.. _pecan_decorators:

:mod:`pecan.decorators` -- Pecan Decorators
===========================================

The :mod:`pecan.decorators` module includes useful decorators for
creating Pecan applications.

.. automodule:: pecan.decorators
  :members:
  :show-inheritance: